API
---

.. module:: flask_collect

This part of the documentation documents all the public classes and
functions in Flask-Collect-Invenio.


Configuration
`````````````

.. autoclass:: Collect
   :members:


Storage
```````

.. autoclass:: flask_collect.storage.base.BaseStorage
   :members:
